@@ -84,7 +84,10 @@ class NDVariable:
         :param arr: The next value to add.
         :type arr: np.ndarray
         """
-        self.vals = np.vstack((self.vals, arr))
+        if self.dims == 1:
+            self.vals = np.append(self.vals, arr)
+        else:
+            self.vals = np.vstack((self.vals, arr))
 
     @property
     def value(self):
@@ -138,28 +141,24 @@ class NDVariable:
     def __len__(self):
         return len(self.vals)
 
-    def __iadd__(self, other):
-        """Adds other to the last value, then appends"""
+    def __in_place_check(self, other):
         if self.dims == 1 and not isinstance(other, np.ndarray):
-            other = np.array([other])
+            # other = np.array([other])
+            pass
         else:
             if not isinstance(other, np.ndarray):
                 raise ValueError("Other must be ndarray")
             elif other.shape != self.value.shape:
-                print(other, self.value)
                 raise ValueError(f"Other must have the same shape. {self.value.shape}")
+
+    def __iadd__(self, other):
+        """Adds other to the last value, then appends"""
+        self.__in_place_check(other)
         self.add(self.value + other)
         return self
 
     def __isub__(self, other):
-        if self.dims == 1 and not isinstance(other, np.ndarray):
-            other = np.array([other])
-        else:
-            if not isinstance(other, np.ndarray):
-                raise ValueError("Other must be ndarray")
-            elif other.shape != self.value.shape:
-                print(other, self.value)
-                raise ValueError(f"Other must have the same shape. {self.value.shape}")
+        self.__in_place_check(other)
         self.add(self.value - other)
         return self
 
@@ -199,4 +198,4 @@ class NDVariable:
         return other - self.value
 
     def __str__(self):
-        return f"{self.name} {self.vals} {self.unit}"
+        return f"{self.name} {self.value} {self.unit}"
